from renku.command.graph import export_graph_command
from rdflib import Graph
import io
import pydotplus
from IPython.display import display, Image
from rdflib.tools.rdf2dot import rdf2dot

def build_graph(revision='HEAD'):
    result = export_graph_command().build().execute(revision_or_range=revision)
    g = Graph()
    g.parse(data=result.output.as_nt_string())
    g = bind_namespaces(g)
    return g

def bind_namespaces(g):
    g.bind("mls", "http://www.w3.org/ns/mls#")
    g.bind("prov", "http://www.w3.org/ns/prov#")
    g.bind("oa", "http://www.w3.org/ns/oa#")
    g.bind("schema", "http://schema.org/")
    g.bind("renku", "https://swissdatasciencecenter.github.io/renku-ontology#")
    return g

def visualize(g):
    stream = io.StringIO()
    rdf2dot(g, stream, opts = {display})
    dg = pydotplus.graph_from_dot_data(stream.getvalue())
    png = dg.create_png()
    display(Image(png))
    